## pycaret

#### pycaret is the free software and open source machine learning library for python programming language. It is built around several popular machine learning libraries in python. It’s primary objective is to simplify problem solving through machine learning by providing an easy to use unified API. 


```python

```
